# A small include file to setup environment variables
# Copyright 2008 by Vincent Fourmond.
# You can do whatever you want with this file.

export CTIOGA="--echo --xpdf --clean-all --math "
if [ "$DEBUG" ]; then
    export CTIOGA="$CTIOGA --debug "
fi;
